@@ -1,5 +1,6 @@
 import asyncio
 import os
+import subprocess
 import requests
 import typer
 
@@ -247,6 +248,28 @@ def frp(port: int = typer.Argument(..., help="The port of the proxy.")):
 
     fast_reverse_proxy(port)
 
+@app.command(short_help="Set a VSCode tunnel for remote development.")
+def tunnel():
+    # Set up cache directory
+    cache_dir = os.path.expanduser('~/.cache/mw/bin')
+    os.makedirs(cache_dir, exist_ok=True)
+    if not os.path.exists(os.path.join(cache_dir, 'code')):
+        download_file_if_not_exists(
+            "https://heywhale-public.oss-cn-shanghai.aliyuncs.com/vscode/code",
+            os.path.join(cache_dir, 'code')
+        )
+    # Make executable
+    print("Make file executable")
+    os.chmod(os.path.join(cache_dir, 'code'), 0o755)
+    # run the command 'code tunnel' and pipe the input and the output
+    process = subprocess.Popen(
+        [os.path.join(cache_dir, 'code'), 'tunnel'],
+        stdin=subprocess.PIPE,
+        stdout=subprocess.PIPE,
+        stderr=subprocess.PIPE,
+        universal_newlines=True
+    )
+    process.wait()
 
 if __name__ == "__main__":
     app()
